==> android-signing-2.2.0-sources.jar: org/jenkinsci/plugins/androidsigning/Messages.java <==
// CHECKSTYLE:OFF

package org.jenkinsci.plugins.androidsigning;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code signedApkMapping.builderDir.displayName}: {@code Output to
     * separate directory}.
     * 
     * @return
     *     {@code Output to separate directory}
     */
    public static String signedApkMapping_builderDir_displayName() {
        return holder.format("signedApkMapping.builderDir.displayName");
    }

    /**
     * Key {@code signedApkMapping.builderDir.displayName}: {@code Output to
     * separate directory}.
     * 
     * @return
     *     {@code Output to separate directory}
     */
    public static Localizable _signedApkMapping_builderDir_displayName() {
        return new Localizable(holder, "signedApkMapping.builderDir.displayName");
    }

    /**
     * Key {@code validation.noProject}: {@code Unable to validate - this
     * step does not have a parent project}.
     * 
     * @return
     *     {@code Unable to validate - this step does not have a parent project}
     */
    public static String validation_noProject() {
        return holder.format("validation.noProject");
    }

    /**
     * Key {@code validation.noProject}: {@code Unable to validate - this
     * step does not have a parent project}.
     * 
     * @return
     *     {@code Unable to validate - this step does not have a parent project}
     */
    public static Localizable _validation_noProject() {
        return new Localizable(holder, "validation.noProject");
    }

    /**
     * Key {@code builderDisplayName}: {@code Sign Android APKs}.
     * 
     * @return
     *     {@code Sign Android APKs}
     */
    public static String builderDisplayName() {
        return holder.format("builderDisplayName");
    }

    /**
     * Key {@code builderDisplayName}: {@code Sign Android APKs}.
     * 
     * @return
     *     {@code Sign Android APKs}
     */
    public static Localizable _builderDisplayName() {
        return new Localizable(holder, "builderDisplayName");
    }

    /**
     * Key {@code validation.noWorkspace}: {@code Unable to validate - this
     * job does not yet have a workspace}.
     * 
     * @return
     *     {@code Unable to validate - this job does not yet have a workspace}
     */
    public static String validation_noWorkspace() {
        return holder.format("validation.noWorkspace");
    }

    /**
     * Key {@code validation.noWorkspace}: {@code Unable to validate - this
     * job does not yet have a workspace}.
     * 
     * @return
     *     {@code Unable to validate - this job does not yet have a workspace}
     */
    public static Localizable _validation_noWorkspace() {
        return new Localizable(holder, "validation.noWorkspace");
    }

    /**
     * Key {@code signedApkMapping.unsignedSibling.displayName}: {@code
     * Output to unsigned APK sibling}.
     * 
     * @return
     *     {@code Output to unsigned APK sibling}
     */
    public static String signedApkMapping_unsignedSibling_displayName() {
        return holder.format("signedApkMapping.unsignedSibling.displayName");
    }

    /**
     * Key {@code signedApkMapping.unsignedSibling.displayName}: {@code
     * Output to unsigned APK sibling}.
     * 
     * @return
     *     {@code Output to unsigned APK sibling}
     */
    public static Localizable _signedApkMapping_unsignedSibling_displayName() {
        return new Localizable(holder, "signedApkMapping.unsignedSibling.displayName");
    }

}

==> android-signing-2.2.3-sources.jar: org/jenkinsci/plugins/androidsigning/Messages.java <==
// CHECKSTYLE:OFF

package org.jenkinsci.plugins.androidsigning;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code signedApkMapping.builderDir.displayName}: {@code Output to
     * separate directory}.
     * 
     * @return
     *     {@code Output to separate directory}
     */
    public static String signedApkMapping_builderDir_displayName() {
        return holder.format("signedApkMapping.builderDir.displayName");
    }

    /**
     * Key {@code signedApkMapping.builderDir.displayName}: {@code Output to
     * separate directory}.
     * 
     * @return
     *     {@code Output to separate directory}
     */
    public static Localizable _signedApkMapping_builderDir_displayName() {
        return new Localizable(holder, "signedApkMapping.builderDir.displayName");
    }

    /**
     * Key {@code validation.noProject}: {@code Unable to validate - this
     * step does not have a parent project}.
     * 
     * @return
     *     {@code Unable to validate - this step does not have a parent project}
     */
    public static String validation_noProject() {
        return holder.format("validation.noProject");
    }

    /**
     * Key {@code validation.noProject}: {@code Unable to validate - this
     * step does not have a parent project}.
     * 
     * @return
     *     {@code Unable to validate - this step does not have a parent project}
     */
    public static Localizable _validation_noProject() {
        return new Localizable(holder, "validation.noProject");
    }

    /**
     * Key {@code builderDisplayName}: {@code Sign Android APKs}.
     * 
     * @return
     *     {@code Sign Android APKs}
     */
    public static String builderDisplayName() {
        return holder.format("builderDisplayName");
    }

    /**
     * Key {@code builderDisplayName}: {@code Sign Android APKs}.
     * 
     * @return
     *     {@code Sign Android APKs}
     */
    public static Localizable _builderDisplayName() {
        return new Localizable(holder, "builderDisplayName");
    }

    /**
     * Key {@code validation.globSearchLimitReached}: {@code Unable to
     * validate - the pattern searched too many files ({0,number,integer})
     * without a match}.
     * 
     * @param arg0
     *      1st format parameter, {@code {0}}, a number.
     * @return
     *     {@code Unable to validate - the pattern searched too many files
     *     ({0,number,integer}) without a match}
     */
    public static String validation_globSearchLimitReached(Object arg0) {
        return holder.format("validation.globSearchLimitReached", arg0);
    }

    /**
     * Key {@code validation.globSearchLimitReached}: {@code Unable to
     * validate - the pattern searched too many files ({0,number,integer})
     * without a match}.
     * 
     * @param arg0
     *      1st format parameter, {@code {0}}, a number.
     * @return
     *     {@code Unable to validate - the pattern searched too many files
     *     ({0,number,integer}) without a match}
     */
    public static Localizable _validation_globSearchLimitReached(Object arg0) {
        return new Localizable(holder, "validation.globSearchLimitReached", arg0);
    }

    /**
     * Key {@code validation.noWorkspace}: {@code Unable to validate - this
     * job does not yet have a workspace}.
     * 
     * @return
     *     {@code Unable to validate - this job does not yet have a workspace}
     */
    public static String validation_noWorkspace() {
        return holder.format("validation.noWorkspace");
    }

    /**
     * Key {@code validation.noWorkspace}: {@code Unable to validate - this
     * job does not yet have a workspace}.
     * 
     * @return
     *     {@code Unable to validate - this job does not yet have a workspace}
     */
    public static Localizable _validation_noWorkspace() {
        return new Localizable(holder, "validation.noWorkspace");
    }

    /**
     * Key {@code signedApkMapping.unsignedSibling.displayName}: {@code
     * Output to unsigned APK sibling}.
     * 
     * @return
     *     {@code Output to unsigned APK sibling}
     */
    public static String signedApkMapping_unsignedSibling_displayName() {
        return holder.format("signedApkMapping.unsignedSibling.displayName");
    }

    /**
     * Key {@code signedApkMapping.unsignedSibling.displayName}: {@code
     * Output to unsigned APK sibling}.
     * 
     * @return
     *     {@code Output to unsigned APK sibling}
     */
    public static Localizable _signedApkMapping_unsignedSibling_displayName() {
        return new Localizable(holder, "signedApkMapping.unsignedSibling.displayName");
    }

}
